A dataset containg the information needed to build a gallerywidget.

data_htmlwidgets

Format

A data frame with six rows and four variables:

href

character, URL target for the link

image

character, URL for the image

title

character, text for the title

subtitle

character text for the subtitle

http://www.diamondse.info/